Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(588)

Unified Diff: Source/platform/ThemeTypes.h

Issue 289163003: Fix build with gcc 4.8 and C++11 support enabled (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Created 6 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/rendering/RenderThemeChromiumDefault.cpp ('k') | Source/platform/mac/ThemeMac.mm » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/platform/ThemeTypes.h
diff --git a/Source/platform/ThemeTypes.h b/Source/platform/ThemeTypes.h
index 5bffca061c3f33814c73c21a39bdf6d8fd52bd66..0acba2fe24e4b4413e0b2cdc03c64703618297f5 100644
--- a/Source/platform/ThemeTypes.h
+++ b/Source/platform/ThemeTypes.h
@@ -29,16 +29,16 @@
namespace WebCore {
enum ControlState {
- HoverState = 1,
- PressedState = 1 << 1,
- FocusState = 1 << 2,
- EnabledState = 1 << 3,
- CheckedState = 1 << 4,
- ReadOnlyState = 1 << 5,
- WindowInactiveState = 1 << 7,
- IndeterminateState = 1 << 8,
- SpinUpState = 1 << 9, // Sub-state for HoverState and PressedState.
- AllStates = 0xffffffff
+ HoverControlState = 1,
+ PressedControlState = 1 << 1,
+ FocusControlState = 1 << 2,
+ EnabledControlState = 1 << 3,
+ CheckedControlState = 1 << 4,
+ ReadOnlyControlState = 1 << 5,
+ WindowInactiveControlState = 1 << 7,
+ IndeterminateControlState = 1 << 8,
+ SpinUpControlState = 1 << 9, // Sub-state for HoverControlState and PressedControlState.
+ AllControlStates = 0xffffffff
};
typedef unsigned ControlStates;
« no previous file with comments | « Source/core/rendering/RenderThemeChromiumDefault.cpp ('k') | Source/platform/mac/ThemeMac.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698